﻿using System.Collections.Generic;
using System.IO;
using System.Linq;

namespace MHoApps.SnippsCode.Helper
{
    /// <summary>
    /// 
    /// </summary>
    /// <summary>
    /// Helfer Klasse für Informationen über Verzeichnisse 
    /// </summary>
    public static class DirectoryItemHelper
    {
        /// <summary>
        /// alle logischen Laufwerke des aktuellen Gerätes auslesen
        /// </summary>
        /// <returns></returns>
        public static List<Model.DirectoryItem> GetLogicalDrives()
        {
            return Directory.GetLogicalDrives().Select(d => new Model.DirectoryItem { FullPath = d, Type = Model.DirectoryItemTypeEnum.Drive }).ToList();
        }

        /// <summary>
        /// gibt alle Elemente des Verzeischnisses zurück
        /// </summary>
        /// <param name="path">der volle Pfad des Verzeichnisses</param>
        /// <returns></returns>
        public static List<Model.DirectoryItem> GetDirectoryItems(string fullPath)
        {
            var items = new List<Model.DirectoryItem>();

            try
            {
                var folders = Directory.GetDirectories(fullPath);
                if (folders.Length > 0)
                    items.AddRange(folders.Select(f => new Model.DirectoryItem { FullPath = f, Type = Model.DirectoryItemTypeEnum.Folder }));
            }
            catch { }

            try
            {
                var file = Directory.GetFiles(fullPath);
                if (file.Length > 0)
                    items.AddRange(file.Select(f => new Model.DirectoryItem { FullPath = f, Type = Model.DirectoryItemTypeEnum.File }));
            }
            catch { }

            return items;
        }

        public static string GetDirectoryItemName(string path)
        {
            if (string.IsNullOrEmpty(path)) return string.Empty;

            var normalizedPath = path.Replace('/', '\\');

            var lastSlashIndex = normalizedPath.LastIndexOf('\\');

            if (lastSlashIndex <= 0) return path;

            return path.Substring(lastSlashIndex + 1);
        }
    }
}
