﻿

using MHoApps.SnippsCode.Helper;
using MHoApps.SnippsCode.Model;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Windows.Input;

namespace MHoApps.SnippsCode.ViewModel
{
    /// <summary>
    /// 
    /// </summary>
    public class DirectoryItemViewModel : Base.ViewModelBase
    {
        
       
        #region Constructor

        /// <summary>
        /// default constructor
        /// </summary>
        public DirectoryItemViewModel()
        {

        }

        public DirectoryItemViewModel(string itemPath, DirectoryItemTypeEnum itemType, ObservableCollection<TabItemViewModel> tabItems)
        {
            ExpandCommand = new Base.RelayCommand(e => Expand());
            OpenFileCommand = new Base.RelayCommand(o => OpenFile());
            FullPath = itemPath;
            Type = itemType;
            _tabItems = tabItems;
            ClearDirectoryItems();
        }



        #endregion

        #region Public Properties

        #region Model Properties
        public string FullPath { get; set; }
        public string Name => DirectoryItemHelper.GetDirectoryItemName(FullPath);

        public DirectoryItemTypeEnum Type { get; set; }
        #endregion

        #region UI Properties

        public string ImageName => Type == DirectoryItemTypeEnum.Drive ? "drive" : (Type == DirectoryItemTypeEnum.File ? "file" : (IsExpanded ? "folder-open" : "folder-close"));

        public ObservableCollection<DirectoryItemViewModel> ChildItems { get; set; }

        
        private ObservableCollection<TabItemViewModel> _tabItems { get; set; }
        public TabItemViewModel SelectedItem { get; set; }

        public bool CanExpand => Type != DirectoryItemTypeEnum.File;

        public bool IsExpanded
        {
            get => ChildItems?.Count(i => i != null) > 0;
            set
            {
                if (value == true)
                    Expand();
                else
                    ClearDirectoryItems();
            }
        }

        #endregion

        #endregion

        #region Commands

        public ICommand ExpandCommand { get; set; }

        public ICommand OpenFileCommand { get; set; }


        #endregion

        #region Command Methods
        private void Expand()
        {
            if (Type == DirectoryItemTypeEnum.File)
                return;

            var children = DirectoryItemHelper.GetDirectoryItems(FullPath);
            ChildItems = new ObservableCollection<DirectoryItemViewModel>(children.Select(item => new DirectoryItemViewModel(item.FullPath, item.Type, _tabItems)));
        }



        private void OpenFile()
        {
            if (Type != DirectoryItemTypeEnum.File)
                return;

            var newTab = new TabItemViewModel(Name, FullPath, _tabItems, new EditorViewModel {Text = File.ReadAllText(FullPath), TextPath = FullPath });

            if(_tabItems.Any(h => h.Header == newTab.Header))
            {
                SelectedItem = newTab;
                return;
            }

            _tabItems.Add(newTab);
            SelectedItem = newTab;

        }

        #endregion

        #region Helper Methods


        private void ClearDirectoryItems()
        {
            ChildItems = new ObservableCollection<DirectoryItemViewModel>();

            if (Type != DirectoryItemTypeEnum.File)
                ChildItems.Add(null);
        }
        #endregion
    }
}
